import HTMLParser
import re

class ParseCappReport(HTMLParser.HTMLParser):
    def __init__(self):
        HTMLParser.HTMLParser.__init__(self)
        self.data_stack=[]
    def handle_data(self, data):
        self.data_stack.append(data)

class Course:
    def __init__(self, name, term):
        self.name = name
	self.term = term

def isAllCaps(string):
    for letter in string:
        if letter.islower():
           return False
    return True
   
def getCoursesTaken(html):
    parser = ParseCappReport()
    parser.feed(html)
    html_text = parser.data_stack
    courses = []
    for i in range(len(html_text)):
        if (len(html_text[i]) == 4 and isAllCaps(html_text[i]) and 
            len(html_text[i+1]) == 4 and html_text[i+1].isdigit() and not
            set([html_text[i+5], html_text[i+6]]).issubset(["F", "NC", "U", "W"]):
	    name = html_text[i]+" "+html_text[i+1]
            if len(html_text[i+4]) == 6:
                term = html_text[i+4]
            else:
                term = html_text[i+5]
            courses.append(Course(name, term))
    return courses
    



from setuptools import setup, find_packages
import sys, os

version = '0.0.7'

setup(name='RPICappReport',
      version=version,
      description="some RPI Capp Report parsing functionality",
      long_description=("retrieve courses taken (and passed)"),
      classifiers=[
        "Topic :: Utilities",
      ],
      packages=['RPICappReport'],
      keywords='RPI Capp Report RPICappReport',
      author='linksapprentice1',
      author_email='linksapprentice1@gmail.com',
      url='http://pythonhosted.org/RPICappReport',
      license= 'MIT',
      include_package_data=True,
      zip_safe=True,
      )
